/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * MapArea.h
 *
 *  Created on: Oct 27, 2010
 *      Author: ltwardon
 */

#ifndef MAPAREA_H_
#define MAPAREA_H_

#include <string>
#include <list>
#include "MapRegion.h"

namespace airobots {

class MapArea {

public:

	enum MapAreaType {
		NOGO,
		ROOM,
		INTEREST,
		PERSON,
		DISTURB,
		OBJECTS,
		NO_TYP
	};

	static const std::string mapAreaTypeValue[];

	MapArea();
	MapArea(MapAreaType type);
	MapArea(MapAreaType type, std::string arenaName, std::list<MapRegion> regions);

	void addRegion(MapRegion region);
	MapAreaType getType() const;
	void setType(MapAreaType type);
	std::string getArenaName() const;
	void setArenaName(std::string arenaName);
	std::list<MapRegion> getRegions() const;
	void setRegions(std::list<MapRegion> regions);
	void removeRegion(std::string regionLabel);
	MapRegion getRegionByLabel(std::string regionLabel) const;
	std::list<MapRegion> getRegionByGroup(std::string group) const;

private:

	std::string arenaName;
	MapAreaType type;
	std::list<MapRegion> regions;

	bool checkRegionLabel(std::string region);
	std::string createNewLabel(MapRegion region);

};

}

#endif /* MAPAREA_H_ */
