/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * KatanaPoseData.cpp
 *
 *  Created on: May 25, 2010
 *      Author: ttoenige
 */

#include "KatanaPoseData.h"

using namespace airobots;
using namespace std;
using namespace xmltio;

std::string KatanaPoseData::getBaseTag()
{
	return "POSITION";
}

std::string KatanaPoseData::getTemplate()
{
	return std::string("<") + getBaseTag() + "><GENERATOR/>"
			+ Timestamp::getTemplate() + "<P x=\"\" y=\"\" z=\"\"/>"
			+ "<ANGLE phi=\"\" psi=\"\" theta=\"\" />" + "</" + getBaseTag()
			+ ">";
}

KatanaPoseData::KatanaPoseData() :
	Type("unknown")
{
	// TODO Auto-generated constructor stub

}

double KatanaPoseData::getX(LengthUnit lengthUnit) const
{
	return UnitConverter::convert(x,MILLIMETER,lengthUnit);
}
void KatanaPoseData::setX(double x,LengthUnit lengthUnit)
{
	this->x = UnitConverter::convert(x,lengthUnit,MILLIMETER);
}

double KatanaPoseData::getY(LengthUnit lengthUnit) const
{
	return UnitConverter::convert(y,MILLIMETER,lengthUnit);
}
void KatanaPoseData::setY(double y,LengthUnit lengthUnit)
{
	this->y = UnitConverter::convert(y,lengthUnit,MILLIMETER);;
}

double KatanaPoseData::getZ(LengthUnit lengthUnit) const
{
	return UnitConverter::convert(z,MILLIMETER,lengthUnit);
}
void KatanaPoseData::setZ(double z,LengthUnit lengthUnit)
{
	this->z = UnitConverter::convert(z,lengthUnit,MILLIMETER);;
}

double KatanaPoseData::getPhi(AngleUnit angleUnit) const
{
	return UnitConverter::convert(phi,RADIAN,angleUnit);
}
void KatanaPoseData::setPhi(double phi,AngleUnit angleUnit)
{
	this->phi = UnitConverter::convert(phi,angleUnit,RADIAN);
}

double KatanaPoseData::getPsi(AngleUnit angleUnit) const
{
	return UnitConverter::convert(psi,RADIAN,angleUnit);
}

void KatanaPoseData::setPsi(double psi,AngleUnit angleUnit)
{
	this->psi = UnitConverter::convert(psi,angleUnit,RADIAN);
}

double KatanaPoseData::getTheta(AngleUnit angleUnit) const
{
	return UnitConverter::convert(theta,RADIAN,angleUnit);
}
void KatanaPoseData::setTheta(double theta,AngleUnit angleUnit)
{
	this->theta = UnitConverter::convert(theta,angleUnit,RADIAN);
}

void KatanaPoseData::sanitizeLocation(xmltio::Location &loc) const
{

}

void KatanaPoseData::fillInto(xmltio::Location &loc) const
{

	Type::fillInto(loc);

	loc[XPath("P/@x")] = getX(MILLIMETER);
	loc[XPath("P/@y")] = getY(MILLIMETER);
	loc[XPath("P/@z")] = getZ(MILLIMETER);

	loc[XPath("ANGLE/@psi")] = getPsi(RADIAN);
	loc[XPath("ANGLE/@phi")] = getPhi(RADIAN);
	loc[XPath("ANGLE/@theta")] = getTheta(RADIAN);

}

void KatanaPoseData::fromLocation(const xmltio::Location &loc_,
		KatanaPoseData &kpd)
{

	Type::fromLocation(loc_, kpd);

	kpd.setX(extract<double> (loc_[XPath("P/@x")]),MILLIMETER);
	kpd.setY(extract<double> (loc_[XPath("P/@y")]),MILLIMETER);
	kpd.setZ(extract<double> (loc_[XPath("P/@z")]),MILLIMETER);

	kpd.setPhi(extract<double> (loc_[XPath("ANGLE/@phi")]),RADIAN);
	kpd.setPsi(extract<double> (loc_[XPath("ANGLE/@psi")]),RADIAN);
	kpd.setTheta(extract<double> (loc_[XPath("ANGLE/@theta")]),RADIAN);

}

