/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * CameraPositionData.h
 *
 *  Created on: Apr 10, 2010
 *      Author: lziegler
 */

#include "CameraPositionData.h"

using namespace airobots;
using namespace std;
using namespace xmltio;

std::string CameraPositionData::getBaseTag() {
	return "CAMERAPOSITION";
}

std::string CameraPositionData::getTemplate() {
	return std::string("<") + getBaseTag() + "><GENERATOR/>"
			+ Timestamp::getTemplate()
			+ "<PAN rad=\"\" />"
			+ "<TILT rad=\"\" />"
			+ "<ZOOM qual=\"\" />" + "</" + getBaseTag() + ">";
}

CameraPositionData::CameraPositionData() :
	Type("unknown") {
}

double CameraPositionData::getTilt(AngleUnit angleUnit) const {
	return UnitConverter::convert(tilt,RADIAN,angleUnit);
}

void CameraPositionData::setTilt(double tilt, AngleUnit angleUnit) {
	this->tilt = UnitConverter::convert(tilt,angleUnit,RADIAN);
}

double CameraPositionData::getPan(AngleUnit angleUnit) const {
	return UnitConverter::convert(pan,RADIAN,angleUnit);
}

void CameraPositionData::setPan(double pan, AngleUnit angleUnit) {
	this->pan = UnitConverter::convert(pan,angleUnit,RADIAN);
}

double CameraPositionData::getZoom() const {
	return zoom;
}

void CameraPositionData::setZoom(double zoom) {
	this->zoom = zoom;
}

void CameraPositionData::sanitizeLocation(xmltio::Location &loc) const {
	
}

void CameraPositionData::fillInto(xmltio::Location &loc) const {

	Type::fillInto(loc);

	loc[XPath("PAN/@rad")] = getPan(RADIAN);

	loc[XPath("TILT/@rad")] = getTilt(RADIAN);

	loc[XPath("ZOOM/@qual")] = getZoom();

}

void CameraPositionData::fromLocation(const xmltio::Location &loc_, CameraPositionData &ctd) {

	Type::fromLocation(loc_, ctd);

	ctd.setPan(extract<double> (loc_[XPath("PAN/@rad")]),RADIAN);

	ctd.setTilt(extract<double> (loc_[XPath("TILT/@rad")]),RADIAN);

	ctd.setZoom(extract<double> (loc_[XPath("ZOOM/@qual")]));

}
