/*
 * PointCloud.h
 *
 *  Created on: Jun 14, 2011
 *      Author: plueckin
 */

#ifndef POINTCLOUD_H_
#define POINTCLOUD_H_


#include <vector>
#include <iostream>
#include "../../Type.h"
#include "../../List.h"
#include "../geometry/Point3D.h"
#include "../geometry/Rotation3D.h"
#include "../../units/UnitConverter.h"

namespace airobots {

class PointCloud : public Type {

public:
	PointCloud();
	PointCloud(std::string generator);
	PointCloud(const PointCloud &pc);
	PointCloud(std::vector<Point3D> points, Point3D ori,
		Rotation3D rot, LengthUnit u);
	virtual ~PointCloud();

	static std::string getBaseTag();
	static std::string getTemplate();

	void fillInto(xmltio::Location &loc) const;
	static void fromLocation(const xmltio::Location &loc, PointCloud &type);
	void sanitizeLocation(xmltio::Location &loc) const;

	std::vector<Point3D> getPoints() const;
	Point3D getSensorOrigin() const;
	Rotation3D getRotation() const;

	void addPoint(Point3D point);
	void setSensorOrigin(Point3D ori);
	void setRotation(Rotation3D rot);

	bool operator==(const PointCloud &other) const;

private:

	std::vector<Point3D> points;
	Point3D sensor_origin;
	Rotation3D rotation;

	LengthUnit iLU;
};

}

#endif /* POINTCLOUD_H_ */
