/*
 * This file is part of Bielefeld Type Library (BTL).
 * 
 * Copyright(c) Frederic Siepmann http://opensource.cit-ec.de/projects/btl
 * 
 * This file may be licensed under the terms of of the GNU Lesser General Public
 * License Version 3 (the ``LGPL''), or (at your option) any later version.
 * 
 * Software distributed under the License is distributed on an ``AS IS'' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the LGPL for the
 * specific language governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this program. If not,
 * go to http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 * 
 * The development of this software was supported by the Excellence Cluster EXC
 * 277 Cognitive Interaction Technology. The Excellence Cluster EXC 277 is a
 * grant of the Deutsche Forschungsgemeinschaft (DFG) in the context of the
 * German Excellence Initiative.
 * 
 * Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman
 * Köster, Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling, Denis
 * Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
 */
package de.unibi.airobots.btl.data.annotation;

import de.unibi.airobots.btl.units.*;

/**
 * 
 * @author jhelbach
 */
public class MapPoint {

	private double x;
	private double y;
	private LengthUnit iLU = LengthUnit.METER;

	private MapPoint.Kind kind;

	private String ref;

	public MapPoint(double x, double y, LengthUnit lU) {
		this.x = UnitConverter.convert(x, lU, iLU);
		this.y = UnitConverter.convert(y, lU, iLU);
		ref = "";
		kind = Kind.WORLD;
	}

	public MapPoint(double x, double y, Kind kind, LengthUnit lU, String ref) {
		super();
		this.x = UnitConverter.convert(x, lU, iLU);
		this.y = UnitConverter.convert(y, lU, iLU);
		this.kind = kind;
		this.ref = ref;
	}

	public MapPoint(MapPoint p) {
		this.x = p.getX(iLU);
		this.y = p.getY(iLU);
		this.kind = p.getKind();
		this.ref = p.getRef();
	}

	public double getX(LengthUnit lU) {
		return UnitConverter.convert(x, iLU, lU);
	}

	public void setX(double x, LengthUnit lU) {
		this.x = UnitConverter.convert(x, lU, iLU);
	}

	public double getY(LengthUnit lU) {
		return UnitConverter.convert(y, iLU, lU);
	}

	public void setY(double y,LengthUnit lU) {
		this.y = UnitConverter.convert(y, lU, iLU);
	}

	public MapPoint.Kind getKind() {
		return kind;
	}

	public void setKind(MapPoint.Kind kind) {
		this.kind = kind;
	}

	public String getRef() {
		return ref;
	}

	public void setRef(String ref) {
		this.ref = ref;
	}

	public enum Kind {
		WORLD, RELATIVE
	}

}
